unit Imgfind;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, ExtCtrls, StdCtrls, FileCtrl, Buttons, inifiles, Menus,
  Univbm;

type
  TimgFinder = class(TForm)
    FileListBox1: TFileListBox;
    DirectoryListBox1: TDirectoryListBox;
    DriveComboBox1: TDriveComboBox;
    FilterComboBox1: TFilterComboBox;
    Panel1: TPanel;
    ScrollBox1: TScrollBox;
    BitBtn1: TBitBtn;
    BitBtn2: TBitBtn;
    Image: TImage;
    Edit1: TEdit;
    DirHistory: TComboBox;
    PopupMenu1: TPopupMenu;
    Delete1: TMenuItem;
    Add1: TMenuItem;
    BitBtn3: TBitBtn;
    BitBtn4: TBitBtn;
    UnivBMLoader1: TUnivBMLoader;
    procedure FileListBox1Change(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure Add1Click(Sender: TObject);
    procedure DirHistoryChange(Sender: TObject);
    procedure Delete1Click(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure FormDestroy(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure BitBtn3Click(Sender: TObject);
    procedure BitBtn4Click(Sender: TObject);
    procedure FilterComboBox1Change(Sender: TObject);
  private
    { Private declarations }
    dirs : TStringList;

    procedure AddDirectory(s : string);
  public
    { Public declarations }
    bmpOnly : boolean;
  end;

var
  imgFinder: TimgFinder;

implementation
uses add_dir,bmpabout;

{$R *.DFM}

procedure TimgFinder.FileListBox1Change(Sender: TObject);
var
  index : integer;

begin
  if FileExists(FileListBox1.FileName) then
    begin
      index:=UnivBMLoader1.FindBMType(copy(ExtractFileExt(FileListBox1.FileName),2,3));

      if index>=0 then
        begin
          UnivBMLoader1.loadFromFile(FileListBox1.FileName);
          image.Picture.Assign(UnivBMLoader1.Bitmap);
        end
      else
        image.Picture.LoadFromFile(FileListBox1.FileName);

      ScrollBox1.HorzScrollBar.Range:=image.picture.width;
      ScrollBox1.VertScrollBar.Range:=image.picture.height;
      ScrollBox1.HorzScrollBar.position:=0;
      ScrollBox1.VertScrollBar.position:=0;

      if image.picture.bitmap<>nil then
        if image.picture.bitmap.empty then
          BitBtn4.enabled:=FALSE
        else
          BitBtn4.enabled:=TRUE;
    end;
end;

procedure TimgFinder.AddDirectory(s : string);
begin
  DirHistory.items.add(copy(s,1,pos('=',s)-1));
end;

procedure TimgFinder.FormCreate(Sender: TObject);
var
  DelphiIni : TIniFile;
  i         : integer;

begin
  if BMPOnly then
    begin
      FilterComboBox1.ItemIndex:=0;
      FileListBox1.Mask:='*.BMP';
    end
  else
    FilterComboBox1.Enabled:=TRUE;

  dirs:=TStringList.Create;
  DelphiIni := TIniFile.Create('delphi.ini');
  DelphiIni.ReadSectionValues('DanielsIMGfinder', Dirs);
  DelphiIni.Free;
end;

procedure TimgFinder.Add1Click(Sender: TObject);
begin
  addDir:=TAddDir.Create(Application);
  try
    addDir.Dir.text:=DirectoryListBox1.Directory;
    addDir.DirName.clear;
    if addDir.ShowModal=mrOK then
      begin
        Dirs.values[addDir.DirName.text]:=addDir.Dir.text;
        AddDirectory(Dirs.strings[Dirs.count-1]);
        dirHistory.ItemIndex:=dirs.count-1;
      end;
  finally
    addDir.Free;
  end;
end;

procedure TimgFinder.DirHistoryChange(Sender: TObject);
begin
  if DirHistory.text<>'' then
    DirectoryListbox1.Directory:=Dirs.values[DirHistory.text];
end;

procedure TimgFinder.Delete1Click(Sender: TObject);
begin
  DirHistory.items.delete(DirHistory.itemIndex);
end;

procedure TimgFinder.FormClose(Sender: TObject; var Action: TCloseAction);
var
  DelphiIni : TIniFile;
  i         : integer;

begin
  DelphiIni := TIniFile.Create('delphi.ini');

  DelphiIni.EraseSection('DanielsIMGfinder');

  for i:=0 to Dirs.count-1 do
    DelphiIni.WriteString('DanielsIMGfinder',
                          DirHistory.items.Strings[i],
                          Dirs.values[DirHistory.items.strings[i]]);

  DelphiIni.Free;
end;

procedure TimgFinder.FormDestroy(Sender: TObject);
begin
  dirs.Free;
end;

procedure TimgFinder.FormShow(Sender: TObject);
var
  i : integer;

begin
  DirHistory.Clear;

  for i:=0 to dirs.count-1 do
    AddDirectory(dirs.strings[i]);

  if dirs.count<>0 then
    begin
      DirHistory.ItemIndex:=0;
      if DirHistory.text<>'' then
        DirectoryListbox1.Directory:=Dirs.values[DirHistory.text];
    end;

  if image.picture.bitmap<>nil then
    if image.picture.bitmap.empty then
      BitBtn4.enabled:=FALSE
    else
      BitBtn4.enabled:=TRUE;

  if bmpOnly then
    FilterComboBox1.Filter:=UnivBMLoader1.Formats
  else
    FilterComboBox1.Filter:=UnivBMLoader1.Formats+'|Windows Metafile|*.WMF';
end;

procedure TimgFinder.BitBtn3Click(Sender: TObject);
begin
  bmpAboutWindow:=TbmpAboutWindow.Create(Application);
  try
    bmpAboutWindow.ShowModal;
  finally
    bmpAboutWindow.Free;
  end;
end;

{
procedure TimgFinder.BitBtn4Click(Sender: TObject);
var
  temp : TBitmap;

begin
  if image.picture.bitmap<>nil then
    begin
      temp:=TBitmap.Create;
      image.picture.bitmap.assign(temp);
      temp.free;

      BitBtn4.enabled:=FALSE;
    end;
end;
}

procedure TimgFinder.BitBtn4Click(Sender: TObject);
var
  temp : TPicture;

begin
  if image.picture<>nil then
    begin
      temp:=TPicture.Create;
      image.picture.assign(temp);
      temp.free;

      BitBtn4.enabled:=FALSE;
    end;
end;

procedure TimgFinder.FilterComboBox1Change(Sender: TObject);
var
  index : integer;

begin
  index:=UnivBMLoader1.FindBMType(copy(FileListBox1.Mask,3,3));
  if BMPOnly and (index=-1) then
    begin
      FilterComboBox1.ItemIndex:=1;
      FileListBox1.Mask:='*.BMP';
    end;
end;

end.
